//
// BarGraphOfLEDs.ino
//
// A sample sketch for introduction to Arduino class
// ©Danny Swarzman, 2013
//
// This sketch reads analog pins A0, A1, A2.
//
// It displays the value of one of them using the six LEDs to form a bar graph
//
////////////////////////////////////////////////////////////////////////////////
//
// The bargraph uses pins 8-13. These comprise port B.
// The program addresses them through PORTB and DDRB, 
// rather than using pin functions

#define kLEDCount 6
//
// The program responds to user commands:
//
// '0' Display potentiometer values.
// '1'  Dispaly photoresistor values.
//
int activeDevice;
static const int kPotentiometerDeviceNumber = 0;
static const int kPhotoresistorDeviceNumber = 1;

// Use ReadingDevicesIntoSerialPort.ino to determine these values
#define kBrightestVoltage 14
#define kDarkestVoltage 1014

// The first element in each of these arrays is the minimimum and maximum
// values that are expected from the potentiometer's analog input.
// The second element in each of these arrays is the minimimum and maximum
// values that are expected from the photoresistor's analog input.

const int kDeviceRangeLower[] = { 0, kBrightestVoltage };
const int kDeviceRangeUpper[] = { 1023, kDarkestVoltage };

////////////////////////////////////////////////////////////////////////////////

void setup()
{
	Serial.begin(9600);
	
	// The default is to get values to display from the photoresistor.
	
	activeDevice = kPhotoresistorDeviceNumber;
	showHelp();
	
	// Bits 0 though 5 of PORTB are used for the LEDs.
	// These correspond to pins 8 through 13 on the Arduino
	
	// Set the bits to be outputs
	DDRB = B00111111;
	
	// Turn them all off to start
	PORTB = 0;	
}

void loop()
{
	if ( Serial.available() )
	{
		char clu = Serial.read();
		switch ( clu )
		{
			case '0':
				activeDevice = kPotentiometerDeviceNumber;
				Serial.println ( F("potentiomenter is now active" ) );
				break;
			case '1':
				activeDevice = kPhotoresistorDeviceNumber;
				Serial.println ( F("photoresistor is now active" ) );
				break;
			case '?':
				showHelp();
				break;
			default :
				break;
		}
	}
	
	int sensorValue = analogRead ( activeDevice );
	int lower = kDeviceRangeLower[activeDevice];
	int upper = kDeviceRangeUpper[activeDevice];
	int mappedValue = map ( sensorValue, upper, lower, 0, kLEDCount + 1 );
	// Mapped value is the number of bits that are shifted off or the 
	// number of LEDs that are dark.
	PORTB = B00111111 >> mappedValue;
}

void showHelp()
{
	Serial.println ( F("BarGraphOfLEDs.ino" ));
	if ( activeDevice == 0 )
	{
		Serial.println ( F("potentiomenter is currently active" ) );
		Serial.println ( F("enter 1 to change it to photoresistor" ));
	}
	else
	{
		Serial.println ( F("photoresistor is currently active" ) );
		Serial.println ( F("enter 0 to change it to potentiomenter" ));
	}
	Serial.println ( F("enter ? to see this" ) );
}