//
// DisplayingLEDsOneAtATime
//
// A sample sketch for introduction to Arduino class
// ©Danny Swarzman, 2013
//
// This sketch controls LEDs 0 to 6, connected to Pins 8 to 13
// on the Arduino.
//
// It is designed to run with a computer connected to the 
// Arduino running the Arduino IDE.
//
// In this sketch the user types into the Serial Monitor 
// window of the Arduino IDE. The sketch recognizes characters
// '0', '1', ... , '5' and toggles the corresponding output pin.
//

#define kLEDCount 6

// Table to translate LED number ( 0-6 ) to pin number
const int kPinNumbers[] = { 8, 9, 10, 11, 12, 13 };

// Keep track of the last value assigned to each LED 
int pinValues[6];
////////////////////////////////////////////////////////////////////////////////

void setup()
{

	Serial.begin(9600);
	showHelp();
	for ( int iPin = 0; iPin<kLEDCount; iPin++ )
	{
		pinValues[iPin] = HIGH;
		pinMode ( kPinNumbers[iPin], OUTPUT );
		digitalWrite ( kPinNumbers[iPin], HIGH );
	}
}

void showHelp()
{
	Serial.println ( F("DisplayingLEDsOneAtATime.ino" ) );
	Serial.println ( F("enter a number in the range 0 to 5" ) );
	Serial.println ( F("to toggle the numbered LED" ) );
	Serial.println ( F("? to see these instructions" ) );
}

void loop()
{
	if ( Serial.available() )
	{
		char clu = Serial.read();
		switch ( clu )
		{
			case '0':
				toggleLED(0);
				break;
			case '1':
				toggleLED(1);
				break;
			case '2':
				toggleLED(2);
				break;
			case '3':
				toggleLED(3);
				break;
			case '4':
				toggleLED(4);
				break;
			case '5':
				toggleLED(5);
				break;
			case '?':
				showHelp();
				break;
		}
	}
}


////////////////////////////////////////////////////////////////////////////////

void toggleLED ( int LEDNumber )
{
	if ( pinValues[LEDNumber] == LOW )
		pinValues[LEDNumber] = HIGH;
	else 
		pinValues[LEDNumber] = LOW;
	digitalWrite ( kPinNumbers[LEDNumber], pinValues[LEDNumber] );
	reportLED(LEDNumber);
}

void reportLED ( int LEDNumber )
{
	Serial.print ( F("LED ") );
	Serial.print ( LEDNumber );
	Serial.print ( F(" set to ") );
	Serial.println ( pinValues[LEDNumber] );
}

	


