//
// DisplayingLEDsWithPorts.ino
//
// A sample sketch for introduction to Arduino class
// ©Danny Swarzman, 2013
//
// This sketch controls 6 LEDs, called LED 0, LED 2, ..., LED 5, connected to Pins 8 to 13
// on the Arduino.
//
// It is designed to run with a computer connected to the 
// Arduino running the Arduino IDE.
//
// In this sketch, instead of controlling pins one at a time,
// The whole set of pins, is changed in one instruction
//
// In this sketch the user types into the Serial Monitor 
// window of the Arduino IDE. The sketch recognizes characters
// '0', '1', ... , '5' and sets the corresponding pin, turning off the other LEDs
//
////////////////////////////////////////////////////////////////////////////////
// !!!: Using Ports
////////////////////////////////////////////////////////////////////////////////
//
// Ports are explained at : http://arduino.cc/en/Reference/PortManipulation
//
// In this sketch, Port B is used. That corresponds to pins 8 to 13
// 
// There are two special variables in the processor to control these pins
//
// One is the data register. Its variable name is PORTB.
//
// Setting or clearing a bit of PORTB has the same result as digitalWrite()
//
// All the bits could be set at once. For example, this would light LED at pin 9
// while turning the others off:
//
//		PORTB = B00000010; // LED 1 only
//
// The other is the data direction register, DDRB
// Setting or clearing a bit of this is the same as pinMode () 
// for the corresponding pin
// 
// For example this makes all the bits, 0 to 6 indicate output, making pins 8-13 output pins
//
//		DDRB = B00111111; // Make outputs for LEDs 0 to 6
//
////////////////////////////////////////////////////////////////////////////////



void setup()
{
	Serial.begin(9600);
	showHelp();
	DDRB = B00111111;
	PORTB = 0;	
}

void showHelp()
{
	Serial.println ( F("DisplayingLEDsWithPorts.ino") );
	Serial.println ( F("Enter a number 0 to 5" ) );
	Serial.print( F("The numbered of LEDs will light.") );
	Serial.println ( F( " The others will go out.") );
	Serial.println ( F("Enter '?' to see this message" ) );
}	


void loop()
{
	if ( Serial.available() )
	{
		char clu = Serial.read();
		switch ( clu )
		{
			case '0':
				selectLED(0);
				break;
			case '1':
				selectLED(1);
				break;
			case '2':
				selectLED(2);
				break;
			case '3':
				selectLED(3);
				break;
			case '4':
				selectLED(4);
				break;
			case '5':
				selectLED(5);
				break;
			case '?':
				showHelp();
				break;
		}
	}
}

////////////////////////////////////////////////////////////////////////////////
// Light one LED and turn the others off
////////////////////////////////////////////////////////////////////////////////


void selectLED ( int LEDNumber )
{
	// Put a 1 in the rightmost position in a byte
	// Push it to the left the the number of positions
	// The resulting set of bits will be right to light the numbered LED.
	
	PORTB = 1 << LEDNumber;
}
	
