//
// IntroducingSerial.ino
//
// A sample sketch for introduction to Arduino class
// ©Danny Swarzman, 2014
// 
// This is the first in a series of sketches.
//
// It is a bare minimm to demonstrate an Arduino sketch
// that interacts with the Serial Monitor inside the Arduino IDE
// 
// To run this program, open the Arduino IDE application in 
// a desktop or laptop.
//
// The computer should be connected via a USB cable to an Arduino.
//
// It doesn't matter if there are devices connected to the pins of the Arduino.
// They won't be used.
//
// Select your model of Arduino in the Tools/Board menu.
// Select a port from the Tools/Port menu. On Mac OS X, pick
// the one that begins '/dev/tty/usbserial'
// Click the second icon from the top left in the window with this file.
// That will upload the program.
// When it is uploaded, uset Tools/SerialMonitor to open the SerialMonitor window.
// Type into this window to see what happens. Type '?' to get help.
//
// You may see the help message appearing more that once. This is normal
// for most models of Arduino. Opening the SerialMonitor window causes
// an extra reset of the processor.
//
// On the Yun, you may see the message at all. If you want reasurance, type ?.
//
////////////////////////////////////////////////////////////////////////////////
//
// There are no #include files here.
//
// Ordinarily a C++ program would have some lines like #include "somename"
// 
// The file Arduino.h is magically included a .ino file
//
// As a result of this magic, an object called Serial is defined and ready
// to be used as setup() begins.
//
////////////////////////////////////////////////////////////////////////////////
//
// Note that the libraries used by the Arduino IDE are in two places.
// There are libraries that build into the application. In Mac OS X, 
// to find these libraries, you must right-click ( or control-click )
// on the Arduino applcation icon and select "Show Package Contents".
// Look inside the contents for the library.
//
// The other library folder is one that you set up for third party libraries.
//
////////////////////////////////////////////////////////////////////////////////
void setup()
{
	Serial.begin(9600);
	showHelp();
}

void loop()
{
	if ( Serial.available() )
	{
		char clu = Serial.read();
		if ( clu == '?' )
			showHelp();
		Serial.print ( clu );
		Serial.print ( " " );
		Serial.print ( clu, HEX );
		Serial.println ( " OK" );
	}
}

////////////////////////////////////////////////////////////////////////////////
//
// Note on the F() macro
//
// One of the big constraints of Arduino programming is the tiny amount of 
// memory for data that is changed by the sketch. 
//
// This constraint becomes a big problem when the sketch has a lot of lines
// line this:
// 	Serial.print ( "my error message" );
//
// The message doesn't change while the progam runs. So it is eligible to be 
// stored in the same space as the program.
// 
// The F() macro does this very nicely. It puts the message into program memory 
// and generates code to fetch it when the statement is executed.
//
// The moral to the story:
//		avoid Serial.print ( "my error message" );
//		instead use Serial.print ( F("my error message" ) );
//
//  http://playground.arduino.cc/Learning/Memory#.UzeSCce1YZc
////////////////////////////////////////////////////////////////////////////////
void showHelp()
{
	Serial.println ( F("IntroducingSerial.ino") );
	Serial.println ( F("type any character, it will be echoed in as text and in Hex") );
	Serial.println ( F("type '?' to see this explanation") );
}	

