//
// ReadingDevicesIntoSerialPort.ino
//
// A sample sketch for introduction to Arduino class
//
// ©Danny Swarzman, 2014
//
// This is used to calibrate the sensor analog input.
//
// It also reads the value the analog input connected to the potentiometer.
//
// It measures values of the two inputs.
//
// The potentiomenter input is used as a sanity check.
//
// With this sketch find and note the lowest and highest values for the
// the voltage coming from the photo resositor.
//
// Note the values. You will need to put them into the source code of
// the final sketch–the one that actually acts as a bar code.
//
//
////////////////////////////////////////////////////////////////////////////////

// Pins A0, A1 are connected to analog devices.

const int kPotentiometerPin = 0;
const int kPhotoResistorPin = 1;

// Periodically the program displays the values in these sensors in
// the serial port.

const unsigned long kReportPeriodMillis = 5000;
unsigned long reportPeriodExpiry;

// Voltage levels are in the units read by the analog input, 0 to 1023
// To find an actual voltage these would be multiplied by 
// 	VCC / 1023
// where VCC is the supply voltage, nominaly 5V.
// The goal is to get values to plug into another sketch which uses 
// the analog input.

const float kSupplyVoltageLevel = 1023;

int darkVoltageLevel;
int brightVoltageLevel;

boolean periodicFlag;					// Periodic reporting is active	

////////////////////////////////////////////////////////////////////////////////

void setup()
{
	Serial.begin(9600);
	showHelp();
	periodicFlag = false;
	reportPeriodExpiry = millis() + kReportPeriodMillis;
}

void showHelp()
{
	Serial.println ( F("ReadingDevicesIntoSerialPort.ino") );
	Serial.println ( F("Commands" ) );
	Serial.println ( F("p : toggle periodic report" ) );
	Serial.println ( F("? : display this menu" ) );
}

void loop()
{
	loopSerial();
	loopReport();
}
	
void loopSerial()
{
	if ( Serial.available() )
	{
		char clu = Serial.read();
		switch ( clu )
		{
			case 'p':
				periodicFlag = !periodicFlag;
				Serial.print ( F("periodic report " ));
				Serial.println ( periodicFlag ? F("on") : F("off") );
				break;
		}
	}
}


// If waiting for user to enter digits for resistor value 
// check the character to see if it is a digit.


void loopReport()
{
	if (periodicFlag && millis() > reportPeriodExpiry )
	{
		reportPeriodExpiry = millis() + kReportPeriodMillis;
		oneReport();
	}
}

void oneReport()
{
	int potentiometer = analogRead(kPotentiometerPin);
	int photoResistor = analogRead(kPhotoResistorPin);
	
	Serial.print ( F("potentiometer " ) );
	Serial.print ( potentiometer );
	Serial.print ( F("   photoResistor " ) );
	Serial.println ( photoResistor );
}



	